@@ -15,48 +15,6 @@ short_description: Hashicorp Vault OIDC secret engine role
 description:
     - Module to define an OIDC role that vault can generate dynamic credentials for vault
 options:
-    url:
-        description:
-            - url for vault
-        default: to environment variable VAULT_ADDR
-    ca_cert:
-        description:
-            - "path to a PEM-encoded CA cert file to use to verify the Vault server TLS certificate"
-        default: to environment variable VAULT_CACERT
-    ca_path:
-        description:
-            - "path to a directory of PEM-encoded CA cert files to verify the Vault server TLS certificate : if ca_cert
-             is specified, its value will take precedence"
-        default: to environment variable VAULT_CAPATH
-    client_cert:
-        description:
-            - "path to a PEM-encoded client certificate for TLS authentication to the Vault server"
-        default: to environment variable VAULT_CLIENT_CERT
-    client_key:
-        description:
-            - "path to an unencrypted PEM-encoded private key matching the client certificate"
-        default: to environment variable VAULT_CLIENT_KEY
-    verify:
-        description:
-            - "if set, do not verify presented TLS certificate before communicating with Vault server : setting this
-             variable is not recommended except during testing"
-        default: to environment variable VAULT_SKIP_VERIFY
-    token:
-        description:
-            - token for vault
-        default: to environment variable VAULT_TOKEN
-    username:
-        description:
-            - username to login to vault.
-        default: to environment variable VAULT_USER
-    password:
-        description:
-            - password to login to vault.
-        default: to environment variable VAULT_PASSWORD
-    namespace:
-        description:
-            - namespace for vault
-        default: to environment variable VAULT_NAMESPACE
     mount_point:
         description:
             - name of the secret engine mount name.
@@ -132,6 +90,7 @@ options:
               default (which unless changed will be service tokens). For token store roles, there are two additional
               possibilities (default-service and default-batch) which specify the type to return unless the client
               requests a different type at generation time.
+extends_documentation_fragment: hashivault
 '''
 EXAMPLES = '''
 ---
